<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage blocktype-statusnetnotice
 * @author     Gregor Anzelj
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2011 Gregor Anzelj, gregor.anzelj@gmail.com
 *
 */

defined('INTERNAL') || die();

class PluginBlocktypeStatusNetNotice extends SystemBlocktype {

    public static function single_only() {
        return true;
    }

    public static function get_title() {
        return get_string('title', 'blocktype.statusnetnotice');
    }

    public static function get_description() {
        return get_string('description', 'blocktype.statusnetnotice');
    }

    public static function get_categories() {
        return array('general');
    }

    public static function render_instance(BlockInstance $instance, $editing=false) {
        $configdata = $instance->get('configdata');
        $align      = (!empty($configdata['align'])) ? hsc($configdata['align']) : 'left';
        $host       = (!empty($configdata['host'])) ? hsc($configdata['host']) : 'http://identi.ca/';
		
		// Add trailing slash, even if $host does not contain it...
		$host = rtrim($host, '/') . '/';
		
		$result  = '<link rel="stylesheet" type="text/css" href="' . get_config('wwwroot') .'blocktype/statusnetnotice/lib/statusnet.css" />';
		$result .= '<div class="' . $align . '">';
        $result .= '<a href="javascript:(function(){var%20d=document,w=window,e=w.getSelection,k=d.getSelection,x=d.selection,s=(e?e():(k)?k():(x?x.createRange().text:0)),f=\'' . $host . '?action=bookmarklet\',l=d.location,e=encodeURIComponent,g=f+\'&status_textarea=%E2%80%9C\'+((e(s))?e(s):e(document.title))+\'%E2%80%9D%20%E2%80%94%20\'+l.href;function%20a(){if(!w.open(g,\'t\',\'toolbar=0,resizable=0,scrollbars=1,status=1,width=450,height=200\')){l.href=g;}}a();})()" class="statusnet-notice-button">' . get_string('notice', 'blocktype.statusnetnotice') . '</a>';
		$result .= '</div>';
		return $result;
    }

    public static function has_instance_config() {
        return true;
    }

    public static function instance_config_form($instance) {
        $configdata = $instance->get('configdata');

        return array(
            'showtitle' => array(
                'type'  => 'checkbox',
                'title' => get_string('showtitle','blocktype.statusnetnotice'),
                'defaultvalue' => (!empty($configdata['showtitle']) ? $configdata['showtitle'] : 0),
            ),
            'host' => array(
                'type' => 'text',
                'title' => get_string('statusnethost','blocktype.statusnetnotice'),
                'description' => get_string('statusnethostdesc','blocktype.statusnetnotice'),
                'defaultvalue' => (!empty($configdata['host']) ? $configdata['host'] : 'http://identi.ca/'),
            ),
            'align' => array(
                'type' => 'radio',
                'title' => get_string('align','blocktype.statusnetnotice'),
                'defaultvalue' => (!empty($configdata['align'])) ? $configdata['align'] : 'left',
				'options' => array(
					'left' => get_string('alignleft','blocktype.statusnetnotice'),
					'center' => get_string('aligncenter','blocktype.statusnetnotice'),
					'right' => get_string('alignright','blocktype.statusnetnotice'),
				),
				'separator' => '&nbsp;&nbsp;&nbsp;',
			),
        );
    }

    public static function instance_config_save($values) {
        if (empty($values['showtitle'])) {
			$values['title'] = null;
		}
		return $values;
	}
	
    public static function default_copy_type() {
        return 'full';
    }

}

?>
